==> lxqt-l10n_0.11.1.orig.tar.xz: lxqt-l10n-0.11.1/lximage-qt/lximage-qt_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../../application.cpp" line="89"/>
        <source>Take a screenshot</source>
        <translation>Faire une copie d&apos;écran</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="93"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FICHIER1,FICHIER2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="148"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="149"/>
        <source>LXImage - a simple and fast image viewer

Copyright (C) 2013
LXDE Project: http://lxde.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>LXImage - un visionneur d&apos;image simple et rapide

Copyright (C) 2013
LXDE Project: http://lxde.org/

Auteurs:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="241"/>
        <source>Open File</source>
        <translation>Ouvrir un fichier</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="242"/>
        <location filename="../../mainwindow.cpp" line="263"/>
        <source>Image files (%1)</source>
        <translation>Fichier image (%1)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="263"/>
        <source>Save File</source>
        <translation>Enregistrer un fichier</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="529"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Chargement...) - Visionneur d&apos;image</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="534"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Échec de chargement) - Visionneur d&apos;image</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="538"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Visionneur d&apos;image</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="575"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Visionneur d&apos;image</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="822"/>
        <source>Thumbnails</source>
        <translation>Miniatures</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Visionneur d&apos;image</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="71"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="77"/>
        <source>Go</source>
        <translation>Aller</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="86"/>
        <source>&amp;View</source>
        <translation>A&amp;fficher</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="100"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="120"/>
        <source>Toolbar</source>
        <translation>Barre des outils</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="159"/>
        <source>&amp;About</source>
        <translation>À &amp;propos</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="169"/>
        <source>&amp;Open File</source>
        <translation>&amp;Ouvrir un fichier</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="172"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="182"/>
        <source>&amp;Save</source>
        <translation>&amp;Enregistrer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="185"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="195"/>
        <source>Save &amp;As</source>
        <translation>Enregistrer &amp;sous</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="198"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="208"/>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="211"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="221"/>
        <source>Zoom &amp;In</source>
        <translation>Zoom a&amp;vant</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="224"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="234"/>
        <source>Zoom &amp;Out</source>
        <translation>Zoom a&amp;rrière</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="237"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="247"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Copie vers le presse-papier</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="257"/>
        <location filename="../../mainwindow.ui" line="260"/>
        <source>Next File</source>
        <translation>Fichier suivant</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="263"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="273"/>
        <location filename="../../mainwindow.ui" line="276"/>
        <source>Previous File</source>
        <translation>Fichier précédent</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="279"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="289"/>
        <source>Original Size</source>
        <translation>Taille d&apos;origine</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="292"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="302"/>
        <source>&amp;Fit</source>
        <translation>Adapter la &amp;taille</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="312"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>&amp;Rotation horaire</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="322"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Rotation &amp;anti-horaire</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="327"/>
        <source>P&amp;references</source>
        <translation>&amp;Préférences</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="332"/>
        <source>&amp;Print</source>
        <translation>&amp;Imprimer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="335"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="345"/>
        <source>First File</source>
        <translation>Premier fichier</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="348"/>
        <source>Home</source>
        <translation>Début</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="358"/>
        <source>Last File</source>
        <translation>Dernier fichier</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="361"/>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="371"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nouvelle fenêtre</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="374"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="379"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Retournement &amp;horizontal</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="389"/>
        <source>Capture Screenshot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="397"/>
        <source>F&amp;ull Screen</source>
        <translation>&amp;Plein écran</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="400"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="405"/>
        <source>Flip &amp;Vertically</source>
        <translation>Retournement &amp;vertical</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="415"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Coller depuis le presse-papier</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="428"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Diaporama</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="438"/>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="441"/>
        <source>Del</source>
        <translation>Suppr</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="449"/>
        <source>Show Thumbnails</source>
        <translation>Afficher les miniatures</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="454"/>
        <source>File Properties</source>
        <translation>Propriétés du fichier</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Thème des icônes :</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>Couleur de fond normale :</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>Couleur de fond en plein écran :</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>Intervale entre diapositives :</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Copie d&apos;écran</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="28"/>
        <source>Take a screenshot</source>
        <translation>Faire une copie d&apos;écran</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="35"/>
        <source>Region</source>
        <translation>Région</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="41"/>
        <source>Whole screen</source>
        <translation>Écran entier</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="51"/>
        <source>Current window only</source>
        <translation>Fenêtre courante seule</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="61"/>
        <source>Include mouse cursor</source>
        <translation>Inclure le pointeur de souris</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="68"/>
        <source> seconds</source>
        <translation> secondes</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="85"/>
        <source>Delay:</source>
        <translation>Délai :</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="95"/>
        <source>Include window title and frame</source>
        <translation>Inclurela barre de titre et le cadre</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lximage-qt/lximage-qt_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../../application.cpp" line="91"/>
        <source>Take a screenshot</source>
        <translation>Faire une copie d&apos;écran</translation>
    </message>
    <message>
        <location filename="../../application.cpp" line="95"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[FICHIER1,FICHIER2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../../mainwindow.cpp" line="143"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="144"/>
        <source>LXImage - a simple and fast image viewer

Copyright (C) 2013
LXDE Project: http://lxde.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>LXImage - un visionneur d&apos;image simple et rapide

Copyright (C) 2013
LXDE Project: http://lxde.org/

Auteurs:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="253"/>
        <source>Open File</source>
        <translation>Ouvrir un fichier</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="254"/>
        <location filename="../../mainwindow.cpp" line="281"/>
        <source>Image files (%1)</source>
        <translation>Fichier image (%1)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="260"/>
        <source>Open directory</source>
        <translation>Ouvrir le répertoire</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="281"/>
        <source>Save File</source>
        <translation>Enregistrer un fichier</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="537"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Chargement...) - Visionneur d&apos;image</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="542"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Échec de chargement) - Visionneur d&apos;image</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="546"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Visionneur d&apos;image</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="582"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Visionneur d&apos;image</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="842"/>
        <source>Thumbnails</source>
        <translation>Miniatures</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Visionneur d&apos;image</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="78"/>
        <source>Go</source>
        <translation>Aller</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="87"/>
        <source>&amp;View</source>
        <translation>A&amp;fficher</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="101"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="121"/>
        <source>Toolbar</source>
        <translation>Barre des outils</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="160"/>
        <source>&amp;About</source>
        <translation>À &amp;propos</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="170"/>
        <source>&amp;Open File</source>
        <translation>&amp;Ouvrir un fichier</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="173"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="183"/>
        <source>&amp;Save</source>
        <translation>&amp;Enregistrer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="186"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="196"/>
        <source>Save &amp;As</source>
        <translation>Enregistrer &amp;sous</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="199"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="209"/>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="212"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="222"/>
        <source>Zoom &amp;In</source>
        <translation>Zoom a&amp;vant</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="225"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="235"/>
        <source>Zoom &amp;Out</source>
        <translation>Zoom a&amp;rrière</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="238"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="248"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Copie vers le presse-papier</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="258"/>
        <location filename="../../mainwindow.ui" line="261"/>
        <source>Next File</source>
        <translation>Fichier suivant</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="264"/>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="274"/>
        <location filename="../../mainwindow.ui" line="277"/>
        <source>Previous File</source>
        <translation>Fichier précédent</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="280"/>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="290"/>
        <source>Original Size</source>
        <translation>Taille d&apos;origine</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="293"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="303"/>
        <source>&amp;Fit</source>
        <translation>Adapter la &amp;taille</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="313"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>&amp;Rotation horaire</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="323"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Rotation &amp;anti-horaire</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="328"/>
        <source>P&amp;references</source>
        <translation>&amp;Préférences</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="333"/>
        <source>&amp;Print</source>
        <translation>&amp;Imprimer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="336"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="346"/>
        <source>First File</source>
        <translation>Premier fichier</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="349"/>
        <source>Home</source>
        <translation>Début</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="359"/>
        <source>Last File</source>
        <translation>Dernier fichier</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="362"/>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="372"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nouvelle fenêtre</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="375"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="380"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Retournement &amp;horizontal</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="390"/>
        <source>Capture Screenshot</source>
        <translation>Capture d&apos;écran</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="398"/>
        <source>F&amp;ull Screen</source>
        <translation>&amp;Plein écran</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="401"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="406"/>
        <source>Flip &amp;Vertically</source>
        <translation>Retournement &amp;vertical</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="416"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Coller depuis le presse-papier</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="429"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Diaporama</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="439"/>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="442"/>
        <source>Del</source>
        <translation>Suppr</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="450"/>
        <source>Show Thumbnails</source>
        <translation>Afficher les miniatures</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="455"/>
        <source>File Properties</source>
        <translation>Propriétés du fichier</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="463"/>
        <source>Open &amp;Directory</source>
        <translation>Ouvrir &amp;répertoire</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="466"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Préférences</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Général</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Thème des icônes :</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>Couleur de fond normale :</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>Couleur de fond en plein écran :</translation>
    </message>
    <message>
        <location filename="../../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>Intervale entre diapositives :</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Copie d&apos;écran</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Faire une copie d&apos;écran</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Région</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Écran entier</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Fenêtre courante seule</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Inclure le pointeur de souris</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="74"/>
        <source> seconds</source>
        <translation> secondes</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Délai :</translation>
    </message>
    <message>
        <location filename="../../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Inclurela barre de titre et le cadre</translation>
    </message>
</context>
</TS>
